@@ -4,7 +4,7 @@ context("Measurement")
 
 test_that("declare_measurement works", {
   design <-
-    declare_population(N = 10, latent = seq(0, 1, length.out = N)) +
+    declare_model(N = 10, latent = seq(0, 1, length.out = N)) +
     declare_measurement(observed = as.numeric(cut(latent, breaks = seq(0, 1, length.out = 6), include.lowest = TRUE)))
   
 
