@@ -1,7 +1,7 @@
 context("Multiple POs")
 
 test_that("multiple potential outcomes", {
-  my_population <- declare_population(
+  my_population <- declare_model(
     N = 100, income = rnorm(N), age = sample(18:95, N, replace = T)
   )
 
