@@ -1,9 +1,9 @@
 context("Subsetting")
 
 test_that("Test Subsetting on default inquiry handler", {
-  my_population <- declare_population(N = 50, noise = rnorm(N))
+  my_population <- declare_model(N = 50, noise = rnorm(N))
 
-  my_potential_outcomes <- declare_potential_outcomes(Y_Z_0 = noise, Y_Z_1 = noise + rnorm(N, mean = 2, sd = 2))
+  my_potential_outcomes <- declare_model(Y_Z_0 = noise, Y_Z_1 = noise + rnorm(N, mean = 2, sd = 2))
 
   my_sampling <- declare_sampling(S = complete_rs(N, n = 25))
 
